@@ -5,6 +5,7 @@ import readcsvturbo as rct
 
 ################### Reading the first and last line from big_csv and getting a df ###################
 csv_file_path = Path("./big_csv.csv")
+csv_file_path = Path("/home/donjor/5mSalesRecords.csv")
 
 print("""
 ############## RAW PANDAS ###############
@@ -62,4 +63,4 @@ print(df)
 
 end_time = time.perf_counter()
 
-print(f'RAW TIME: {round(end_time-start_time,2)}s\n')
\ No newline at end of file
+print(f'TURBO TIME: {round(end_time-start_time,2)}s\n')
\ No newline at end of file
